summaryrefslogtreecommitdiff
path: root/gtk2_ardour/midi_region_view.h
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2010-09-17 18:20:37 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2010-09-17 18:20:37 +0000
commitede4ecbb00ecc866c502454c81e711baea780ccd (patch)
treed4a05e59cc96651ddf0eeab929f58fb7a7019fb0 /gtk2_ardour/midi_region_view.h
parent10bdce85a0e7381d1b5db38e3640600c6fd3ec79 (diff)
megaopus patch #2 for today: remove nframes64_t and sframes_t from source
git-svn-id: svn://localhost/ardour2/branches/3.0@7792 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/midi_region_view.h')
-rw-r--r--gtk2_ardour/midi_region_view.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/gtk2_ardour/midi_region_view.h b/gtk2_ardour/midi_region_view.h
index baf67928c8..4e4e9544c5 100644
--- a/gtk2_ardour/midi_region_view.h
+++ b/gtk2_ardour/midi_region_view.h
@@ -118,7 +118,7 @@ class MidiRegionView : public RegionView
void resolve_note(uint8_t note_num, double end_time);
void cut_copy_clear (Editing::CutCopyOp);
- void paste (nframes64_t pos, float times, const MidiCutBuffer&);
+ void paste (framepos_t pos, float times, const MidiCutBuffer&);
struct PCEvent {
PCEvent(double a_time, uint8_t a_value, uint8_t a_channel)
@@ -253,21 +253,21 @@ class MidiRegionView : public RegionView
/** Snap a region relative pixel coordinate to frame units.
* @param x a pixel coordinate relative to region start
* @return the snapped nframes64_t coordinate relative to region start
*/
- nframes64_t snap_pixel_to_frame(double x);
+ framepos_t snap_pixel_to_frame(double x);
/** Snap a region relative frame coordinate to frame units.
* @param x a pixel coordinate relative to region start
* @return the snapped nframes64_t coordinate relative to region start
*/
- nframes64_t snap_frame_to_frame(nframes64_t x);
+ framepos_t snap_frame_to_frame(framepos_t x);
/** Convert a timestamp in beats to frames (both relative to region start) */
- nframes64_t beats_to_frames(double beats) const;
+ framepos_t beats_to_frames(double beats) const;
/** Convert a timestamp in frames to beats (both relative to region start) */
- double frames_to_beats(nframes64_t) const;
+ double frames_to_beats(framepos_t) const;
void goto_previous_note ();
void goto_next_note ();
@@ -253,21 +253,21 @@ class MidiRegionView : public RegionView
/** Snap a region relative pixel coordinate to frame units.
* @param x a pixel coordinate relative to region start
- * @return the snapped nframes64_t coordinate relative to region start
+ * @return the snapped framepos_t coordinate relative to region start
*/
@@ -253,21 +253,21 @@ class MidiRegionView : public RegionView
/** Snap a region relative frame coordinate to frame units.
* @param x a pixel coordinate relative to region start
- * @return the snapped nframes64_t coordinate relative to region start
+ * @return the snapped framepos_t coordinate relative to region start
*/